views

package
v0.0.0-...-0250c29 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 23, 2026 License: BSD-3-Clause Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	// ProjectUpdateMap is a map indexing the attribute names of ProjectUpdate by
	// view name.
	ProjectUpdateMap = map[string][]string{
		"default": {
			"id",
			"body",
		},
	}
	// PendingInvitesMap is a map indexing the attribute names of PendingInvites by
	// view name.
	PendingInvitesMap = map[string][]string{
		"default": {
			"pending",
			"projects",
		},
	}
	// ProjectMap is a map indexing the attribute names of Project by view name.
	ProjectMap = map[string][]string{
		"default": {
			"id",
			"name",
			"description",
			"goal",
			"location",
			"tags",
			"privacy",
			"startTime",
			"endTime",
			"photo",
			"readOnly",
			"showStations",
			"bounds",
			"following",
		},
	}
	// ProjectsMap is a map indexing the attribute names of Projects by view name.
	ProjectsMap = map[string][]string{
		"default": {
			"projects",
		},
	}
	// DownloadedPhotoMap is a map indexing the attribute names of DownloadedPhoto
	// by view name.
	DownloadedPhotoMap = map[string][]string{
		"default": {
			"length",
			"body",
			"contentType",
			"etag",
		},
	}
	// ProjectsBasicMap is a map indexing the attribute names of ProjectsBasic by
	// view name.
	ProjectsBasicMap = map[string][]string{
		"default": {
			"projects",
		},
	}
	// ProjectCollectionMap is a map indexing the attribute names of
	// ProjectCollection by view name.
	ProjectCollectionMap = map[string][]string{
		"default": {
			"id",
			"name",
			"description",
			"goal",
			"location",
			"tags",
			"privacy",
			"startTime",
			"endTime",
			"photo",
			"readOnly",
			"showStations",
			"bounds",
			"following",
		},
	}
	// ProjectBasicCollectionMap is a map indexing the attribute names of
	// ProjectBasicCollection by view name.
	ProjectBasicCollectionMap = map[string][]string{
		"default": {
			"id",
			"name",
		},
	}
	// ProjectBasicMap is a map indexing the attribute names of ProjectBasic by
	// view name.
	ProjectBasicMap = map[string][]string{
		"default": {
			"id",
			"name",
		},
	}
)

Functions

func ValidateDownloadedPhoto

func ValidateDownloadedPhoto(result *DownloadedPhoto) (err error)

ValidateDownloadedPhoto runs the validations defined on the viewed result type DownloadedPhoto.

func ValidateDownloadedPhotoView

func ValidateDownloadedPhotoView(result *DownloadedPhotoView) (err error)

ValidateDownloadedPhotoView runs the validations defined on DownloadedPhotoView using the "default" view.

func ValidatePendingInviteView

func ValidatePendingInviteView(result *PendingInviteView) (err error)

ValidatePendingInviteView runs the validations defined on PendingInviteView.

func ValidatePendingInvites

func ValidatePendingInvites(result *PendingInvites) (err error)

ValidatePendingInvites runs the validations defined on the viewed result type PendingInvites.

func ValidatePendingInvitesView

func ValidatePendingInvitesView(result *PendingInvitesView) (err error)

ValidatePendingInvitesView runs the validations defined on PendingInvitesView using the "default" view.

func ValidateProject

func ValidateProject(result *Project) (err error)

ValidateProject runs the validations defined on the viewed result type Project.

func ValidateProjectBasicCollectionView

func ValidateProjectBasicCollectionView(result ProjectBasicCollectionView) (err error)

ValidateProjectBasicCollectionView runs the validations defined on ProjectBasicCollectionView using the "default" view.

func ValidateProjectBasicView

func ValidateProjectBasicView(result *ProjectBasicView) (err error)

ValidateProjectBasicView runs the validations defined on ProjectBasicView using the "default" view.

func ValidateProjectBoundsView

func ValidateProjectBoundsView(result *ProjectBoundsView) (err error)

ValidateProjectBoundsView runs the validations defined on ProjectBoundsView.

func ValidateProjectCollectionView

func ValidateProjectCollectionView(result ProjectCollectionView) (err error)

ValidateProjectCollectionView runs the validations defined on ProjectCollectionView using the "default" view.

func ValidateProjectFollowingView

func ValidateProjectFollowingView(result *ProjectFollowingView) (err error)

ValidateProjectFollowingView runs the validations defined on ProjectFollowingView.

func ValidateProjectSummaryView

func ValidateProjectSummaryView(result *ProjectSummaryView) (err error)

ValidateProjectSummaryView runs the validations defined on ProjectSummaryView.

func ValidateProjectUpdate

func ValidateProjectUpdate(result *ProjectUpdate) (err error)

ValidateProjectUpdate runs the validations defined on the viewed result type ProjectUpdate.

func ValidateProjectUpdateView

func ValidateProjectUpdateView(result *ProjectUpdateView) (err error)

ValidateProjectUpdateView runs the validations defined on ProjectUpdateView using the "default" view.

func ValidateProjectView

func ValidateProjectView(result *ProjectView) (err error)

ValidateProjectView runs the validations defined on ProjectView using the "default" view.

func ValidateProjects

func ValidateProjects(result *Projects) (err error)

ValidateProjects runs the validations defined on the viewed result type Projects.

func ValidateProjectsBasic

func ValidateProjectsBasic(result *ProjectsBasic) (err error)

ValidateProjectsBasic runs the validations defined on the viewed result type ProjectsBasic.

func ValidateProjectsBasicView

func ValidateProjectsBasicView(result *ProjectsBasicView) (err error)

ValidateProjectsBasicView runs the validations defined on ProjectsBasicView using the "default" view.

func ValidateProjectsView

func ValidateProjectsView(result *ProjectsView) (err error)

ValidateProjectsView runs the validations defined on ProjectsView using the "default" view.

Types

type DownloadedPhoto

type DownloadedPhoto struct {
	// Type to project
	Projected *DownloadedPhotoView
	// View to render
	View string
}

DownloadedPhoto is the viewed result type that is projected based on a view.

type DownloadedPhotoView

type DownloadedPhotoView struct {
	Length      *int64
	ContentType *string
	Etag        *string
	Body        []byte
}

DownloadedPhotoView is a type that runs validations on a projected type.

type PendingInviteView

type PendingInviteView struct {
	ID      *int64
	Project *ProjectSummaryView
	Time    *int64
	Role    *int32
}

PendingInviteView is a type that runs validations on a projected type.

type PendingInvites

type PendingInvites struct {
	// Type to project
	Projected *PendingInvitesView
	// View to render
	View string
}

PendingInvites is the viewed result type that is projected based on a view.

type PendingInvitesView

type PendingInvitesView struct {
	Pending  []*PendingInviteView
	Projects ProjectCollectionView
}

PendingInvitesView is a type that runs validations on a projected type.

type Project

type Project struct {
	// Type to project
	Projected *ProjectView
	// View to render
	View string
}

Project is the viewed result type that is projected based on a view.

type ProjectBasicCollectionView

type ProjectBasicCollectionView []*ProjectBasicView

ProjectBasicCollectionView is a type that runs validations on a projected type.

type ProjectBasicView

type ProjectBasicView struct {
	ID   *int32
	Name *string
}

ProjectBasicView is a type that runs validations on a projected type.

type ProjectBoundsView

type ProjectBoundsView struct {
	Min []float64
	Max []float64
}

ProjectBoundsView is a type that runs validations on a projected type.

type ProjectCollectionView

type ProjectCollectionView []*ProjectView

ProjectCollectionView is a type that runs validations on a projected type.

type ProjectFollowingView

type ProjectFollowingView struct {
	Total     *int32
	Following *bool
}

ProjectFollowingView is a type that runs validations on a projected type.

type ProjectSummaryView

type ProjectSummaryView struct {
	ID   *int64
	Name *string
}

ProjectSummaryView is a type that runs validations on a projected type.

type ProjectUpdate

type ProjectUpdate struct {
	// Type to project
	Projected *ProjectUpdateView
	// View to render
	View string
}

ProjectUpdate is the viewed result type that is projected based on a view.

type ProjectUpdateView

type ProjectUpdateView struct {
	ID        *int64
	Body      *string
	CreatedAt *int64
}

ProjectUpdateView is a type that runs validations on a projected type.

type ProjectView

type ProjectView struct {
	ID           *int32
	Name         *string
	Description  *string
	Goal         *string
	Location     *string
	Tags         *string
	Privacy      *int32
	StartTime    *string
	EndTime      *string
	Photo        *string
	ReadOnly     *bool
	ShowStations *bool
	Bounds       *ProjectBoundsView
	Following    *ProjectFollowingView
}

ProjectView is a type that runs validations on a projected type.

type Projects

type Projects struct {
	// Type to project
	Projected *ProjectsView
	// View to render
	View string
}

Projects is the viewed result type that is projected based on a view.

type ProjectsBasic

type ProjectsBasic struct {
	// Type to project
	Projected *ProjectsBasicView
	// View to render
	View string
}

ProjectsBasic is the viewed result type that is projected based on a view.

type ProjectsBasicView

type ProjectsBasicView struct {
	Projects ProjectBasicCollectionView
}

ProjectsBasicView is a type that runs validations on a projected type.

type ProjectsView

type ProjectsView struct {
	Projects ProjectCollectionView
}

ProjectsView is a type that runs validations on a projected type.

Jump to