Documentation
¶
Index ¶
- Variables
- func ValidateStationNote(result *StationNote) (err error)
- func ValidateStationNoteAuthorPhotoView(result *StationNoteAuthorPhotoView) (err error)
- func ValidateStationNoteAuthorView(result *StationNoteAuthorView) (err error)
- func ValidateStationNoteView(result *StationNoteView) (err error)
- func ValidateStationNotes(result *StationNotes) (err error)
- func ValidateStationNotesView(result *StationNotesView) (err error)
- type StationNote
- type StationNoteAuthorPhotoView
- type StationNoteAuthorView
- type StationNoteView
- type StationNotes
- type StationNotesView
Constants ¶
This section is empty.
Variables ¶
var ( // StationNotesMap is a map indexing the attribute names of StationNotes by // view name. StationNotesMap = map[string][]string{ "default": { "notes", }, } // StationNoteMap is a map indexing the attribute names of StationNote by view // name. StationNoteMap = map[string][]string{ "default": { "id", "createdAt", "updatedAt", "author", "body", }, } )
Functions ¶
func ValidateStationNote ¶
func ValidateStationNote(result *StationNote) (err error)
ValidateStationNote runs the validations defined on the viewed result type StationNote.
func ValidateStationNoteAuthorPhotoView ¶
func ValidateStationNoteAuthorPhotoView(result *StationNoteAuthorPhotoView) (err error)
ValidateStationNoteAuthorPhotoView runs the validations defined on StationNoteAuthorPhotoView.
func ValidateStationNoteAuthorView ¶
func ValidateStationNoteAuthorView(result *StationNoteAuthorView) (err error)
ValidateStationNoteAuthorView runs the validations defined on StationNoteAuthorView.
func ValidateStationNoteView ¶
func ValidateStationNoteView(result *StationNoteView) (err error)
ValidateStationNoteView runs the validations defined on StationNoteView using the "default" view.
func ValidateStationNotes ¶
func ValidateStationNotes(result *StationNotes) (err error)
ValidateStationNotes runs the validations defined on the viewed result type StationNotes.
func ValidateStationNotesView ¶
func ValidateStationNotesView(result *StationNotesView) (err error)
ValidateStationNotesView runs the validations defined on StationNotesView using the "default" view.
Types ¶
type StationNote ¶
type StationNote struct {
// Type to project
Projected *StationNoteView
// View to render
View string
}
StationNote is the viewed result type that is projected based on a view.
type StationNoteAuthorPhotoView ¶
type StationNoteAuthorPhotoView struct {
URL *string
}
StationNoteAuthorPhotoView is a type that runs validations on a projected type.
type StationNoteAuthorView ¶
type StationNoteAuthorView struct {
ID *int32
Name *string
Photo *StationNoteAuthorPhotoView
}
StationNoteAuthorView is a type that runs validations on a projected type.
type StationNoteView ¶
type StationNoteView struct {
ID *int32
CreatedAt *int64
UpdatedAt *int64
Author *StationNoteAuthorView
Body *string
}
StationNoteView is a type that runs validations on a projected type.
type StationNotes ¶
type StationNotes struct {
// Type to project
Projected *StationNotesView
// View to render
View string
}
StationNotes is the viewed result type that is projected based on a view.
type StationNotesView ¶
type StationNotesView struct {
Notes []*StationNoteView
}
StationNotesView is a type that runs validations on a projected type.